@@ -572,16 +572,12 @@ class Commands:
 
         return get_reply
 
-    def set_inst(self, type=None, rotxy=None, rotyz=None, rotxz=None, led=None) -> [bytes]:
+    def set_inst(self, rotxy=None, rotyz=None, rotxz=None, led=None) -> [bytes]:
 
         self._reset_buffer()
 
         set_inst_command = b'SETINST'
 
-        if type is not None:
-            # TODO: Implement the type parameter
-            pass
-
         if rotxy is not None:
             if isinstance(rotxy, float) or isinstance(rotxy, int):
                 set_inst_command += b',ROTXY=' + str(rotxy).encode()
@@ -1559,7 +1555,7 @@ class Commands:
 
         return get_reply
 
-    def get_id(self, sn=False, str=False) -> [bytes]:
+    def get_id(self, sn=False, str=False, _timeout = 1) -> [bytes]:
 
         self._reset_buffer()
 
@@ -1575,7 +1571,7 @@ class Commands:
 
         self.connection.write(command)
 
-        get_reply = self._handle_reply(command=command, terminator=b'OK\r\n')
+        get_reply = self._handle_reply(command=command, terminator=b'OK\r\n', timeout=_timeout)
 
         return get_reply
 
@@ -1730,6 +1726,8 @@ class Commands:
 
     def clear_assert(self) -> [bytes]:
 
+        print('CLEARING ASSERTS')
+
         self._reset_buffer()
 
         set_default_mission_command = b'CLEARASSERT\r\n'
@@ -1804,6 +1802,8 @@ class Commands:
 
         listfiles_command += b'\r\n'
 
+        print('LISTFILES COMMAND: {}'.format(listfiles_command))
+
         self.connection.write(listfiles_command)
 
         get_reply = self._handle_reply(command=listfiles_command, terminator=b'OK\r\n', timeout=10)
